==> ZenTaoALM.11.6.2.int.zip: zentaoalm/module/dev/lang/de.php <==
<?php
$lang->dev->common     = 'Entwicklung';
$lang->dev->api        = 'API';
$lang->dev->db         = 'Datenbank';
$lang->dev->editor     = 'Bearbeiter';
$lang->dev->dbList     = 'Datenbank';
$lang->dev->moduleList = 'Module';
$lang->dev->params     = 'Parameter';
$lang->dev->type       = 'Typ';
$lang->dev->desc       = 'Beschreibung';
$lang->dev->noParams   = 'Keine Parameter';
$lang->dev->post       = 'POST Parameter';

$lang->dev->paramRange  = 'Parameter Range: %s';
$lang->dev->paramDate   = 'Date format: YY-mm-dd, e.g 2019-01-01';
$lang->dev->paramColor  = 'Color format: #RGB, e.g. #3da7f5';
$lang->dev->paramMailto = "User account. Separate accounts by ','.";

$lang->dev->fields = array();
$lang->dev->fields['id']     = 'ID';
$lang->dev->fields['name']   = 'Feld';
$lang->dev->fields['desc']   = 'Beschreibung';
$lang->dev->fields['type']   = 'Typ';
$lang->dev->fields['length'] = 'Länge';
$lang->dev->fields['null']   = 'Null';

$lang->dev->tableList = array();
$lang->dev->tableList['action']           = 'Aktion';
$lang->dev->tableList['bug']              = 'Bug';
$lang->dev->tableList['build']            = 'Build';
$lang->dev->tableList['burn']             = 'Burndown';
$lang->dev->tableList['case']             = 'Testfall';
$lang->dev->tableList['casestep']         = 'Testfallschritte';
$lang->dev->tableList['company']          = 'Unternehmen';
$lang->dev->tableList['config']           = 'Config';
$lang->dev->tableList['custom']           = 'Custom';
$lang->dev->tableList['dept']             = 'Abteilung';
$lang->dev->tableList['doc']              = 'Dok';
$lang->dev->tableList['doclib']           = 'Dok Bibliothek';
$lang->dev->tableList['effort']           = 'Aufwand';
$lang->dev->tableList['extension']        = 'Erweiterung';
$lang->dev->tableList['file']             = 'Datei';
$lang->dev->tableList['group']            = 'Gruppe';
$lang->dev->tableList['grouppriv']        = 'Berechtigungen';
$lang->dev->tableList['history']          = 'Verlauf';
$lang->dev->tableList['lang']             = 'Sprache';
$lang->dev->tableList['module']           = 'Modul';
$lang->dev->tableList['product']          = $lang->productCommon;
$lang->dev->tableList['productplan']      = $lang->productCommon . 'Plan';
$lang->dev->tableList['project']          = $lang->projectCommon;
$lang->dev->tableList['projectproduct']   = $lang->projectCommon . $lang->productCommon;
$lang->dev->tableList['projectstory']     = $lang->projectCommon . 'Story';
$lang->dev->tableList['release']          = 'Release';
$lang->dev->tableList['story']            = 'Story';
$lang->dev->tableList['storyspec']        = 'Beschreibung';
$lang->dev->tableList['task']             = 'Aufgabe';
$lang->dev->tableList['taskestimate']     = 'geplanter Aufwand';
$lang->dev->tableList['team']             = 'Team';
$lang->dev->tableList['testresult']       = 'Test Ergbnisse';
$lang->dev->tableList['testrun']          = 'Test ausführen ';
$lang->dev->tableList['testtask']         = 'Testaufgabe';
$lang->dev->tableList['todo']             = 'Todo';
$lang->dev->tableList['user']             = 'Benutzer';
$lang->dev->tableList['usercontact']      = 'Benutzer Kontakt';
$lang->dev->tableList['usergroup']        = 'Benutzer Gruppe';
$lang->dev->tableList['userquery']        = 'Benutzer Abfrage';
$lang->dev->tableList['usertpl']          = 'Benutzer Vorlage';
$lang->dev->tableList['admin']            = 'Admin';
$lang->dev->tableList['api']              = 'API';
$lang->dev->tableList['backup']           = 'Backup';
$lang->dev->tableList['common']           = 'Common';
$lang->dev->tableList['convert']          = 'Konvertieren';
$lang->dev->tableList['dev']              = 'Entwickeln';
$lang->dev->tableList['editor']           = 'Editor';
$lang->dev->tableList['git']              = 'GIT';
$lang->dev->tableList['index']            = 'Home';
$lang->dev->tableList['install']          = 'Installation';
$lang->dev->tableList['mail']             = 'Email';
$lang->dev->tableList['misc']             = 'Sonstiges';
$lang->dev->tableList['my']               = 'Dashboard';
$lang->dev->tableList['qa']               = 'QA';
$lang->dev->tableList['report']           = 'Berichte';
$lang->dev->tableList['search']           = 'Suche';
$lang->dev->tableList['sso']              = 'SSO';
$lang->dev->tableList['svn']              = 'SVN';
$lang->dev->tableList['testcase']         = 'Testfall';
$lang->dev->tableList['testreport']       = 'Test Bericht';
$lang->dev->tableList['testsuite']        = 'Test Suite';
$lang->dev->tableList['tree']             = 'Modulbaum';
$lang->dev->tableList['upgrade']          = 'Update';
$lang->dev->tableList['cron']             = 'Geplanter Task';
$lang->dev->tableList['datatable']        = 'Tabelle';
$lang->dev->tableList['block']            = 'Block';
$lang->dev->tableList['branch']           = 'Branch';
$lang->dev->tableList['doccontent']       = 'Dok Inhalt';
$lang->dev->tableList['storystage']       = 'Story Phase';
$lang->dev->tableList['translate']        = 'Translate';
$lang->dev->tableList['tutorial']         = 'Anleitung';
$lang->dev->tableList['suitecase']        = 'Suite Case';
$lang->dev->tableList['score']            = 'Score';
$lang->dev->tableList['entry']            = 'Eintrag';
$lang->dev->tableList['webhook']          = 'WebHook';
$lang->dev->tableList['log']              = 'Log';
$lang->dev->tableList['message']          = 'Nachricht';
$lang->dev->tableList['notify']           = 'Benachrichtigen';
$lang->dev->tableList['userview']         = 'User Privilege';
$lang->dev->tableList['im_chatuser']      = 'Client Users';
$lang->dev->tableList['im_message']       = 'Client Messages';
$lang->dev->tableList['translation']      = 'Translation';
$lang->dev->tableList['im_messagestatus'] = 'Client Messages Status';

$lang->dev->groupList['my']      = 'Dashboard';
$lang->dev->groupList['product'] = $lang->productCommon;
$lang->dev->groupList['project'] = $lang->projectCommon;
$lang->dev->groupList['qa']      = 'QA';
$lang->dev->groupList['doc']     = 'Dok';
$lang->dev->groupList['report']  = 'Report';
$lang->dev->groupList['company'] = 'Unternehmen';
$lang->dev->groupList['repo']    = 'Code';
$lang->dev->groupList['api']     = 'API';
$lang->dev->groupList['message'] = 'Message';

$lang->dev->endGroupList['admin']  = 'Admin';
$lang->dev->endGroupList['system'] = 'System';
$lang->dev->endGroupList['other']  = 'Andere';

==> ZenTaoALM.12.4.1.int.zip: zentaoalm/module/dev/lang/de.php <==
<?php
$lang->dev->common     = 'Entwicklung';
$lang->dev->api        = 'API';
$lang->dev->db         = 'Datenbank';
$lang->dev->editor     = 'Bearbeiter';
$lang->dev->translate  = 'Translate';
$lang->dev->dbList     = 'Datenbank';
$lang->dev->moduleList = 'Module';
$lang->dev->params     = 'Parameter';
$lang->dev->type       = 'Typ';
$lang->dev->desc       = 'Beschreibung';
$lang->dev->noParams   = 'Keine Parameter';
$lang->dev->post       = 'POST Parameter';

$lang->dev->paramRange    = 'Parameter Range: %s';
$lang->dev->paramDate     = 'Date format: YY-mm-dd, e.g 2019-01-01';
$lang->dev->paramColor    = 'Color format: #RGB, e.g. #3da7f5';
$lang->dev->paramMailto   = "User account. Separate accounts by ','.";
$lang->dev->noteEditor    = "The editor is disabled for security reasons. To use this feature, please go to the official website to download and install the plugin of the <a href='https://www.zentao.pm/extension-viewExt-150.html' target='_blank'>editor</a>.";
$lang->dev->noteTranslate = "The translation is disabled for security reasons. To use this feature, please go to the official website to download and install the plugin of <a href='https://www.zentao.pm/extension-viewExt-151.html' target='_blank'>translation</a>.";

$lang->dev->fields = array();
$lang->dev->fields['id']     = 'ID';
$lang->dev->fields['name']   = 'Feld';
$lang->dev->fields['desc']   = 'Beschreibung';
$lang->dev->fields['type']   = 'Typ';
$lang->dev->fields['length'] = 'Länge';
$lang->dev->fields['null']   = 'Null';

$lang->dev->tableList = array();
$lang->dev->tableList['action']           = 'Aktion';
$lang->dev->tableList['bug']              = 'Bug';
$lang->dev->tableList['build']            = 'Build';
$lang->dev->tableList['burn']             = 'Burndown';
$lang->dev->tableList['case']             = 'Testfall';
$lang->dev->tableList['casestep']         = 'Testfallschritte';
$lang->dev->tableList['company']          = 'Unternehmen';
$lang->dev->tableList['config']           = 'Config';
$lang->dev->tableList['custom']           = 'Custom';
$lang->dev->tableList['dept']             = 'Abteilung';
$lang->dev->tableList['doc']              = 'Dok';
$lang->dev->tableList['doclib']           = 'Dok Bibliothek';
$lang->dev->tableList['effort']           = 'Aufwand';
$lang->dev->tableList['extension']        = 'Erweiterung';
$lang->dev->tableList['file']             = 'Datei';
$lang->dev->tableList['group']            = 'Gruppe';
$lang->dev->tableList['grouppriv']        = 'Berechtigungen';
$lang->dev->tableList['history']          = 'Verlauf';
$lang->dev->tableList['lang']             = 'Sprache';
$lang->dev->tableList['module']           = 'Modul';
$lang->dev->tableList['product']          = $lang->productCommon;
$lang->dev->tableList['productplan']      = $lang->productCommon . 'Plan';
$lang->dev->tableList['project']          = $lang->projectCommon;
$lang->dev->tableList['projectproduct']   = $lang->projectCommon . $lang->productCommon;
$lang->dev->tableList['projectstory']     = $lang->projectCommon . 'Story';
$lang->dev->tableList['release']          = 'Release';
$lang->dev->tableList['story']            = 'Story';
$lang->dev->tableList['storyspec']        = 'Beschreibung';
$lang->dev->tableList['task']             = 'Aufgabe';
$lang->dev->tableList['taskestimate']     = 'geplanter Aufwand';
$lang->dev->tableList['team']             = 'Team';
$lang->dev->tableList['testresult']       = 'Test Ergbnisse';
$lang->dev->tableList['testrun']          = 'Test ausführen ';
$lang->dev->tableList['testtask']         = 'Testaufgabe';
$lang->dev->tableList['todo']             = 'Todo';
$lang->dev->tableList['user']             = 'Benutzer';
$lang->dev->tableList['usercontact']      = 'Benutzer Kontakt';
$lang->dev->tableList['usergroup']        = 'Benutzer Gruppe';
$lang->dev->tableList['userquery']        = 'Benutzer Abfrage';
$lang->dev->tableList['usertpl']          = 'Benutzer Vorlage';
$lang->dev->tableList['admin']            = 'Admin';
$lang->dev->tableList['api']              = 'API';
$lang->dev->tableList['backup']           = 'Backup';
$lang->dev->tableList['common']           = 'Common';
$lang->dev->tableList['convert']          = 'Konvertieren';
$lang->dev->tableList['dev']              = 'Entwickeln';
$lang->dev->tableList['git']              = 'GIT';
$lang->dev->tableList['index']            = 'Home';
$lang->dev->tableList['install']          = 'Installation';
$lang->dev->tableList['mail']             = 'Email';
$lang->dev->tableList['misc']             = 'Sonstiges';
$lang->dev->tableList['my']               = 'Dashboard';
$lang->dev->tableList['qa']               = 'QA';
$lang->dev->tableList['report']           = 'Berichte';
$lang->dev->tableList['search']           = 'Suche';
$lang->dev->tableList['sso']              = 'SSO';
$lang->dev->tableList['svn']              = 'SVN';
$lang->dev->tableList['testcase']         = 'Testfall';
$lang->dev->tableList['testreport']       = 'Test Bericht';
$lang->dev->tableList['testsuite']        = 'Test Suite';
$lang->dev->tableList['caselib']          = 'Case Library';
$lang->dev->tableList['tree']             = 'Modulbaum';
$lang->dev->tableList['upgrade']          = 'Update';
$lang->dev->tableList['cron']             = 'Geplanter Task';
$lang->dev->tableList['datatable']        = 'Tabelle';
$lang->dev->tableList['block']            = 'Block';
$lang->dev->tableList['branch']           = 'Branch';
$lang->dev->tableList['doccontent']       = 'Dok Inhalt';
$lang->dev->tableList['storystage']       = 'Story Phase';
$lang->dev->tableList['tutorial']         = 'Anleitung';
$lang->dev->tableList['suitecase']        = 'Suite Case';
$lang->dev->tableList['score']            = 'Score';
$lang->dev->tableList['entry']            = 'Eintrag';
$lang->dev->tableList['webhook']          = 'WebHook';
$lang->dev->tableList['log']              = 'Log';
$lang->dev->tableList['message']          = 'Nachricht';
$lang->dev->tableList['notify']           = 'Benachrichtigen';
$lang->dev->tableList['userview']         = 'User Privilege';
$lang->dev->tableList['repo']             = 'Code';
$lang->dev->tableList['repohistory']      = 'Repo History';
$lang->dev->tableList['repofiles']        = 'Repo Files';
$lang->dev->tableList['repobranch']       = 'Repo Branch';
$lang->dev->tableList['ci']               = 'CI';
$lang->dev->tableList['compile']          = 'Compile';
$lang->dev->tableList['jenkins']          = 'Jenkins';
$lang->dev->tableList['job']              = 'Job';

$lang->dev->groupList['my']      = 'Dashboard';
$lang->dev->groupList['product'] = $lang->productCommon;
$lang->dev->groupList['project'] = $lang->projectCommon;
$lang->dev->groupList['qa']      = 'QA';
$lang->dev->groupList['doc']     = 'Dok';
$lang->dev->groupList['report']  = 'Report';
$lang->dev->groupList['company'] = 'Unternehmen';
$lang->dev->groupList['repo']    = 'CI';
$lang->dev->groupList['api']     = 'API';
$lang->dev->groupList['message'] = 'Message';

$lang->dev->endGroupList['admin']  = 'Admin';
$lang->dev->endGroupList['system'] = 'System';
$lang->dev->endGroupList['other']  = 'Andere';
